==> google_cloud_retail-2.5.0-py3-none-any.whl: google/cloud/retail_v2alpha/services/catalog_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
import google.protobuf
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.retail_v2alpha import gapic_version as package_version
from google.cloud.retail_v2alpha.types import catalog
from google.cloud.retail_v2alpha.types import catalog as gcr_catalog
from google.cloud.retail_v2alpha.types import catalog_service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)

if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__


class CatalogServiceTransport(abc.ABC):
    """Abstract transport class for CatalogService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "retail.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'retail.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes
        if not hasattr(self, "_ignore_credentials"):
            self._ignore_credentials: bool = False

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None and not self._ignore_credentials:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_catalogs: gapic_v1.method.wrap_method(
                self.list_catalogs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_catalog: gapic_v1.method.wrap_method(
                self.update_catalog,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_default_branch: gapic_v1.method.wrap_method(
                self.set_default_branch,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_default_branch: gapic_v1.method.wrap_method(
                self.get_default_branch,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_completion_config: gapic_v1.method.wrap_method(
                self.get_completion_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_completion_config: gapic_v1.method.wrap_method(
                self.update_completion_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_attributes_config: gapic_v1.method.wrap_method(
                self.get_attributes_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_attributes_config: gapic_v1.method.wrap_method(
                self.update_attributes_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.add_catalog_attribute: gapic_v1.method.wrap_method(
                self.add_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.remove_catalog_attribute: gapic_v1.method.wrap_method(
                self.remove_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.batch_remove_catalog_attributes: gapic_v1.method.wrap_method(
                self.batch_remove_catalog_attributes,
                default_timeout=None,
                client_info=client_info,
            ),
            self.replace_catalog_attribute: gapic_v1.method.wrap_method(
                self.replace_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_operation: gapic_v1.method.wrap_method(
                self.get_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_operations: gapic_v1.method.wrap_method(
                self.list_operations,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_catalogs(
        self,
    ) -> Callable[
        [catalog_service.ListCatalogsRequest],
        Union[
            catalog_service.ListCatalogsResponse,
            Awaitable[catalog_service.ListCatalogsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_catalog(
        self,
    ) -> Callable[
        [catalog_service.UpdateCatalogRequest],
        Union[gcr_catalog.Catalog, Awaitable[gcr_catalog.Catalog]],
    ]:
        raise NotImplementedError()

    @property
    def set_default_branch(
        self,
    ) -> Callable[
        [catalog_service.SetDefaultBranchRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_default_branch(
        self,
    ) -> Callable[
        [catalog_service.GetDefaultBranchRequest],
        Union[
            catalog_service.GetDefaultBranchResponse,
            Awaitable[catalog_service.GetDefaultBranchResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_completion_config(
        self,
    ) -> Callable[
        [catalog_service.GetCompletionConfigRequest],
        Union[catalog.CompletionConfig, Awaitable[catalog.CompletionConfig]],
    ]:
        raise NotImplementedError()

    @property
    def update_completion_config(
        self,
    ) -> Callable[
        [catalog_service.UpdateCompletionConfigRequest],
        Union[catalog.CompletionConfig, Awaitable[catalog.CompletionConfig]],
    ]:
        raise NotImplementedError()

    @property
    def get_attributes_config(
        self,
    ) -> Callable[
        [catalog_service.GetAttributesConfigRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def update_attributes_config(
        self,
    ) -> Callable[
        [catalog_service.UpdateAttributesConfigRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def add_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.AddCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def remove_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.RemoveCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def batch_remove_catalog_attributes(
        self,
    ) -> Callable[
        [catalog_service.BatchRemoveCatalogAttributesRequest],
        Union[
            catalog_service.BatchRemoveCatalogAttributesResponse,
            Awaitable[catalog_service.BatchRemoveCatalogAttributesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def replace_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.ReplaceCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest],
        Union[
            operations_pb2.ListOperationsResponse,
            Awaitable[operations_pb2.ListOperationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_operation(
        self,
    ) -> Callable[
        [operations_pb2.GetOperationRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("CatalogServiceTransport",)

==> google_cloud_retail-2.7.0-py3-none-any.whl: google/cloud/retail_v2alpha/services/catalog_service/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union

import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
import google.auth  # type: ignore
from google.auth import credentials as ga_credentials  # type: ignore
from google.cloud.location import locations_pb2  # type: ignore
from google.longrunning import operations_pb2  # type: ignore
from google.oauth2 import service_account  # type: ignore
import google.protobuf
from google.protobuf import empty_pb2  # type: ignore

from google.cloud.retail_v2alpha import gapic_version as package_version
from google.cloud.retail_v2alpha.types import catalog
from google.cloud.retail_v2alpha.types import catalog as gcr_catalog
from google.cloud.retail_v2alpha.types import catalog_service

DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
    gapic_version=package_version.__version__
)

if hasattr(DEFAULT_CLIENT_INFO, "protobuf_runtime_version"):  # pragma: NO COVER
    DEFAULT_CLIENT_INFO.protobuf_runtime_version = google.protobuf.__version__


class CatalogServiceTransport(abc.ABC):
    """Abstract transport class for CatalogService."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "retail.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: Optional[ga_credentials.Credentials] = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        api_audience: Optional[str] = None,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to (default: 'retail.googleapis.com').
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): Deprecated. A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials. This argument will be
                removed in the next major version of this library.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes
        if not hasattr(self, "_ignore_credentials"):
            self._ignore_credentials: bool = False

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None and not self._ignore_credentials:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )
            # Don't apply audience if the credentials file passed from user.
            if hasattr(credentials, "with_gdch_audience"):
                credentials = credentials.with_gdch_audience(
                    api_audience if api_audience else host
                )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

    @property
    def host(self):
        return self._host

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_catalogs: gapic_v1.method.wrap_method(
                self.list_catalogs,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_catalog: gapic_v1.method.wrap_method(
                self.update_catalog,
                default_timeout=None,
                client_info=client_info,
            ),
            self.set_default_branch: gapic_v1.method.wrap_method(
                self.set_default_branch,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_default_branch: gapic_v1.method.wrap_method(
                self.get_default_branch,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_completion_config: gapic_v1.method.wrap_method(
                self.get_completion_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_completion_config: gapic_v1.method.wrap_method(
                self.update_completion_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_attributes_config: gapic_v1.method.wrap_method(
                self.get_attributes_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_attributes_config: gapic_v1.method.wrap_method(
                self.update_attributes_config,
                default_timeout=None,
                client_info=client_info,
            ),
            self.add_catalog_attribute: gapic_v1.method.wrap_method(
                self.add_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.remove_catalog_attribute: gapic_v1.method.wrap_method(
                self.remove_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.batch_remove_catalog_attributes: gapic_v1.method.wrap_method(
                self.batch_remove_catalog_attributes,
                default_timeout=None,
                client_info=client_info,
            ),
            self.replace_catalog_attribute: gapic_v1.method.wrap_method(
                self.replace_catalog_attribute,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_operation: gapic_v1.method.wrap_method(
                self.get_operation,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_operations: gapic_v1.method.wrap_method(
                self.list_operations,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def list_catalogs(
        self,
    ) -> Callable[
        [catalog_service.ListCatalogsRequest],
        Union[
            catalog_service.ListCatalogsResponse,
            Awaitable[catalog_service.ListCatalogsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_catalog(
        self,
    ) -> Callable[
        [catalog_service.UpdateCatalogRequest],
        Union[gcr_catalog.Catalog, Awaitable[gcr_catalog.Catalog]],
    ]:
        raise NotImplementedError()

    @property
    def set_default_branch(
        self,
    ) -> Callable[
        [catalog_service.SetDefaultBranchRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_default_branch(
        self,
    ) -> Callable[
        [catalog_service.GetDefaultBranchRequest],
        Union[
            catalog_service.GetDefaultBranchResponse,
            Awaitable[catalog_service.GetDefaultBranchResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_completion_config(
        self,
    ) -> Callable[
        [catalog_service.GetCompletionConfigRequest],
        Union[catalog.CompletionConfig, Awaitable[catalog.CompletionConfig]],
    ]:
        raise NotImplementedError()

    @property
    def update_completion_config(
        self,
    ) -> Callable[
        [catalog_service.UpdateCompletionConfigRequest],
        Union[catalog.CompletionConfig, Awaitable[catalog.CompletionConfig]],
    ]:
        raise NotImplementedError()

    @property
    def get_attributes_config(
        self,
    ) -> Callable[
        [catalog_service.GetAttributesConfigRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def update_attributes_config(
        self,
    ) -> Callable[
        [catalog_service.UpdateAttributesConfigRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def add_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.AddCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def remove_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.RemoveCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def batch_remove_catalog_attributes(
        self,
    ) -> Callable[
        [catalog_service.BatchRemoveCatalogAttributesRequest],
        Union[
            catalog_service.BatchRemoveCatalogAttributesResponse,
            Awaitable[catalog_service.BatchRemoveCatalogAttributesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def replace_catalog_attribute(
        self,
    ) -> Callable[
        [catalog_service.ReplaceCatalogAttributeRequest],
        Union[catalog.AttributesConfig, Awaitable[catalog.AttributesConfig]],
    ]:
        raise NotImplementedError()

    @property
    def list_operations(
        self,
    ) -> Callable[
        [operations_pb2.ListOperationsRequest],
        Union[
            operations_pb2.ListOperationsResponse,
            Awaitable[operations_pb2.ListOperationsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_operation(
        self,
    ) -> Callable[
        [operations_pb2.GetOperationRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("CatalogServiceTransport",)
